@@ -29,6 +29,8 @@
 
 #include "gnokii.h"
 
+#define _(String) String
+
 struct UICStruct {
 	GtkListStore *storeNumber;
 	GtkWidget *searchEntry;
@@ -130,7 +132,7 @@ void oneResultSignal_cb(
 	gchar *text;
 					
 	if (retCode = CI_NOT_FOUND) {
-		text = g_strdup_printf("Pas de rponse pour %s", (gchar *) gtk_entry_get_text(GTK_ENTRY(uic->searchEntry)));
+		text = g_strdup_printf(_("ContactInfos found nothing for %s"), (gchar *) gtk_entry_get_text(GTK_ENTRY(uic->searchEntry)));
 		hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_INFO, text);
 		g_free(text);
 	}
@@ -748,7 +750,7 @@ int main( int argc, char *argv[] ) {
 
 	/* Create a new window */
         app = HILDON_PROGRAM( hildon_program_get_instance() );
-        g_set_application_name(("PhoneLink" ));
+        g_set_application_name(_("PhoneLink" ));
 	
         /* Create HildonAppView and set it to HildonApp */
         appview = HILDON_WINDOW( hildon_window_new());
